# Table of Contents

- [data-object-modeling-guidelines](<./data-object-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Data Object Modeling Guidelines](<./Data-Object-Modeling-Guidelines.md>)
  - [Definition](<./Data-Object-Modeling-Guidelines/Definition.md>)
  - [Description](<./Data-Object-Modeling-Guidelines/Description.md>)
  - [Guidelines and Best Practices](<./Data-Object-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [How to Model Data Objects for Data Classification](<./Data-Object-Modeling-Guidelines/How-to-Model-Data-Objects-for-Data-Classification.md>)
  - [How to Model Data Objects for CRUD on the Application Landscape](<./Data-Object-Modeling-Guidelines/How-to-Model-Data-Objects-for-CRUD-on-the-Application-Landscape.md>)
  - [Antipatterns](<./Data-Object-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Data-Object-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from Data Object Fact Sheet](<./Data-Object-Modeling-Guidelines/Insights-from-Data-Object-Fact-Sheet.md>)
  - [Related Information](<./Data-Object-Modeling-Guidelines/Related-Information.md>)
  - [Was this page helpful?](<./Data-Object-Modeling-Guidelines/Was-this-page-helpful.md>)
